pub struct ReadFileRequest { /* private fields */ }Trait Implementations
Sourceimpl Debug for ReadFileRequest
impl Debug for ReadFileRequest
Sourceimpl<'de> Deserialize<'de> for ReadFileRequest
impl<'de> Deserialize<'de> for ReadFileRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReadFileRequest
impl JsonSchema for ReadFileRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReadFileRequest
impl RefUnwindSafe for ReadFileRequest
impl Send for ReadFileRequest
impl Sync for ReadFileRequest
impl Unpin for ReadFileRequest
impl UnsafeUnpin for ReadFileRequest
impl UnwindSafe for ReadFileRequest