pub struct ReadFileResponse { /* private fields */ }Trait Implementations
Sourceimpl Debug for ReadFileResponse
impl Debug for ReadFileResponse
Sourceimpl JsonSchema for ReadFileResponse
impl JsonSchema for ReadFileResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReadFileResponse
impl RefUnwindSafe for ReadFileResponse
impl Send for ReadFileResponse
impl Sync for ReadFileResponse
impl Unpin for ReadFileResponse
impl UnsafeUnpin for ReadFileResponse
impl UnwindSafe for ReadFileResponse