pub struct WriteFileResponse { /* private fields */ }Trait Implementations
Sourceimpl Debug for WriteFileResponse
impl Debug for WriteFileResponse
Sourceimpl JsonSchema for WriteFileResponse
impl JsonSchema for WriteFileResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WriteFileResponse
impl RefUnwindSafe for WriteFileResponse
impl Send for WriteFileResponse
impl Sync for WriteFileResponse
impl Unpin for WriteFileResponse
impl UnsafeUnpin for WriteFileResponse
impl UnwindSafe for WriteFileResponse